<?php
/*
Plugin Name: WP-Simplify
Plugin URI: http://UsabilityDynamics.com/plugins/wp-simplify/
Description: Disable comments, posts, tools, hide unapplicable dashboard metaboxes, etc.
Author: Usability Dynamics, Inc
Version: 1.1
Author URI: http://UsabilityDynamics.com

Copyright 2011  Usability Dynamics, Inc.   (email : andy.potanin@UsabilityDynamics.com)

Created by Usability Dynamics, Inc
(website: UsabilityDynamics.com       email : support@UsabilityDynamics.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; version 3 of the License.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


if(!class_exists('JSMin') && !class_exists('W3_Plugin'))
  include 'extras/jsmin.php';



// Register activation hook -> has to be in the main plugin file
 register_deactivation_hook(__FILE__,'wp_simplify_deactivation');


 function wp_simplify_deactivation() {

  delete_option('wp_simplify');

  $WP_Roles = new WP_Roles;

   foreach($WP_Roles->roles as $role => $role_caps) {

    if($role == 'administrator') {
      $WP_Roles->add_cap($role,'edit_themes');
      $WP_Roles->add_cap($role,'edit_plugins');
    }

  }


 }


/**
 * WP-Simplify General Functions
 *
 * Contains all the general functions used by the plugin.
 *
 * @version 0.60
 * @author Andy Potanin <andy.potanin@usabilitydynamics.com>
 * @package WP-Simplify
 */
 class WP_Simplify {
  


   /**
   * Adds all the plugin hooks
   *
   *
   * @since 0.5
   */
  function WP_Simplify() {
    global $wpdb;

    add_action('init', array('WP_Simplify', 'init'));
    add_action('admin_init', array('WP_Simplify', 'admin_init'));
    add_action('load-options-general.php', array('WP_Simplify', 'general_settings_admin'));
    add_action('admin_menu', array('WP_Simplify', 'admin_menu'), 99);
    add_action('admin_head', array('WP_Simplify', 'admin_head'));
    add_action('favorite_actions', array('WP_Simplify', 'favorite_actions'));
    add_action('template_redirect', array('WP_Simplify', 'template_redirect'), 1);
    add_action('widgets_init', array('WP_Simplify', 'widgets_init'));
    add_action('wp_dashboard_setup', array('WP_Simplify', 'wp_dashboard_setup'));


   }
   
/**
   * Deletes all posts, pages, taxonomies and comments.
   *
   * @since 0.60
   *
   */
  function init() {

     
     
    $wp_simplify = get_option('wp_simplify');

    // If no settings exist, do nothing.
    if(!is_array($wp_simplify))
      return;


    if(wp_verify_nonce($_REQUEST['wp_simplify_nonce'], "wp_simplify_update")) {      

      // Perform WordPress blanking
      if(in_array('enabled_advanced_functions', $wp_simplify) &&  $_REQUEST['blank_wordpress'] == 'Blank WordPress') {
        WP_Simplify::blank_wordpress();
      }
    }

   
    

    if(!in_array('disable_theme_editor', $wp_simplify)) {
      // enable edit_themes

      $WP_Roles = new WP_Roles;


      foreach($WP_Roles->roles as $role => $role_caps) {

        if($role == 'administrator') {
          $WP_Roles->add_cap($role,'edit_themes');
          $WP_Roles->add_cap($role,'edit_plugins');
        }

      }

    } else {


      $WP_Roles = new WP_Roles;
       foreach($WP_Roles->roles as $role => $role_caps) {

           $WP_Roles->remove_cap($role,'edit_themes');
           $WP_Roles->remove_cap($role,'edit_plugins');

        }
    }

  }

  
  /**
   * Deletes all posts, pages, taxonomies and comments.
   *
   * @since 0.60
   *
   */
  function blank_wordpress() {
    global $wpdb;
    
    $wpdb->query("TRUNCATE TABLE {$wpdb->prefix}terms");
    $wpdb->query("TRUNCATE TABLE {$wpdb->prefix}term_relationships");
    $wpdb->query("TRUNCATE TABLE {$wpdb->prefix}posts");
    $wpdb->query("TRUNCATE TABLE {$wpdb->prefix}postmeta");
    $wpdb->query("TRUNCATE TABLE {$wpdb->prefix}comments");
    $wpdb->query("TRUNCATE TABLE {$wpdb->prefix}commentmeta");
    $wpdb->query("TRUNCATE TABLE {$wpdb->prefix}term_taxonomy");
    $wpdb->query("DELETE FROM {$wpdb->prefix}options WHERE option_name = 'wpp_settings'");
  
  }
  
  
  
 /**
  * Front-end functions.
  *
  *
  * @since 0.5
  */
  function template_redirect() {

    $wp_simplify = get_option('wp_simplify');


    if(!is_array($wp_simplify))
      return;

    if(in_array('force_ssl_on_front_end', $wp_simplify)) {
      if ($_SERVER['HTTPS'] != "on") {
      $url = "https://". $_SERVER['SERVER_NAME'] . $_SERVER['REQUEST_URI'];
      header("Location: $url");
      exit;
      }
    }


  }

  function admin_header() {
    global $menu, $submenu;
    echo '<div class="wp_simplify_header_tl"><a href="'.admin_url('index.php').'">Return to dashboard</a></div>';

    echo "<div id='header_menu'><ul>";
    WP_Simplify::header_menu($menu, $submenu);
    echo "</ul></div>";

  }

  function header_menu( $menu, $submenu, $submenu_as_parent = true ) {


  global $self, $parent_file, $submenu_file, $plugin_page, $pagenow, $typenow;

  $first = true;
  // 0 = name, 1 = capability, 2 = file, 3 = class, 4 = id, 5 = icon src
  foreach ( $menu as $key => $item ) {
    $admin_is_parent = false;
    $class = array();
    if ( $first ) {
      $class[] = 'wp-first-item';
      $first = false;
    }
    if ( !empty($submenu[$item[2]]) )
      $class[] = 'wp-has-submenu';

    if ( ( $parent_file && $item[2] == $parent_file ) || ( false === strpos($parent_file, '?') && $self == $item[2] ) ) {
      if ( !empty($submenu[$item[2]]) )
        $class[] = 'wp-has-current-submenu wp-menu-open';
      else
        $class[] = 'current';
    }

    if ( ! empty($item[4]) )
      $class[] = $item[4];

    $class = $class ? ' class="' . join( ' ', $class ) . '"' : '';
    $tabindex = ' tabindex="1"';
    $id = ! empty($item[5]) ? ' id="' . preg_replace( '|[^a-zA-Z0-9_:.]|', '-', $item[5] ) . '"' : '';
    $img = '';
    if ( ! empty($item[6]) ) {
      if ( 'div' === $item[6] )
        $img = '<br />';
      else
        $img = '<img src="' . $item[6] . '" alt="" />';
    }
    $toggle = '<div class="wp-menu-toggle"><br /></div>';

    $title = wptexturize($item[0]);

    echo "\n\t<li$class$id>";

    if ( false !== strpos($class, 'wp-menu-separator') ) {
      echo '<a class="separator" href="?unfoldmenu=1"><br /></a>';
    } elseif ( $submenu_as_parent && !empty($submenu[$item[2]]) ) {
      $submenu[$item[2]] = array_values($submenu[$item[2]]);  // Re-index.
      $menu_hook = get_plugin_page_hook($submenu[$item[2]][0][2], $item[2]);
      $menu_file = $submenu[$item[2]][0][2];
      if ( false !== $pos = strpos($menu_file, '?') )
        $menu_file = substr($menu_file, 0, $pos);
      if ( ( ('index.php' != $submenu[$item[2]][0][2]) && file_exists(WP_PLUGIN_DIR . "/$menu_file") ) || !empty($menu_hook)) {
        $admin_is_parent = true;
        echo "<div class='wp-menu-image'><a href='admin.php?page={$submenu[$item[2]][0][2]}'>$img</a></div>$toggle<a href='admin.php?page={$submenu[$item[2]][0][2]}'$class$tabindex>$title</a>";
      } else {
        echo "\n\t<div class='wp-menu-image'><a href='{$submenu[$item[2]][0][2]}'>$img</a></div>$toggle<a href='{$submenu[$item[2]][0][2]}'$class$tabindex>$title</a>";
      }
    } else if ( @current_user_can($item[1]) ) {
      $menu_hook = get_plugin_page_hook($item[2], 'admin.php');
      $menu_file = $item[2];
      if ( false !== $pos = strpos($menu_file, '?') )
        $menu_file = substr($menu_file, 0, $pos);
      if ( ('index.php' != $item[2]) && file_exists(WP_PLUGIN_DIR . "/$menu_file") || !empty($menu_hook) ) {
        $admin_is_parent = true;
        echo "\n\t<div class='wp-menu-image'><a href='admin.php?page={$item[2]}'>$img</a></div>$toggle<a href='admin.php?page={$item[2]}'$class$tabindex>{$item[0]}</a>";
      } else {
        echo "\n\t<div class='wp-menu-image'><a href='{$item[2]}'>$img</a></div>$toggle<a href='{$item[2]}'$class$tabindex>{$item[0]}</a>";
      }
    }

    if ( !empty($submenu[$item[2]]) ) {
      echo "\n\t<div class='wp-submenu'><div class='wp-submenu-head'>{$item[0]}</div><ul>";
      $first = true;
      foreach ( $submenu[$item[2]] as $sub_key => $sub_item ) {
        if ( !current_user_can($sub_item[1]) )
          continue;

        $class = array();
        if ( $first ) {
          $class[] = 'wp-first-item';
          $first = false;
        }

        $menu_file = $item[2];

        if ( false !== $pos = strpos($menu_file, '?') )
          $menu_file = substr($menu_file, 0, $pos);

        // Handle current for post_type=post|page|foo pages, which won't match $self.
        if ( !empty($typenow) )
          $self_type = $self . '?post_type=' . $typenow;
        else
          $self_type = 'nothing';

        if ( isset($submenu_file) ) {
          if ( $submenu_file == $sub_item[2] )
            $class[] = 'current';
        // If plugin_page is set the parent must either match the current page or not physically exist.
        // This allows plugin pages with the same hook to exist under different parents.
        } else if ( (isset($plugin_page) && $plugin_page == $sub_item[2] && (!file_exists($menu_file) || ($item[2] == $self) || ($item[2] == $self_type))) || (!isset($plugin_page) && $self == $sub_item[2]) ) {
          $class[] = 'current';
        }

        $class = $class ? ' class="' . join( ' ', $class ) . '"' : '';

        $menu_hook = get_plugin_page_hook($sub_item[2], $item[2]);
        $sub_file = $sub_item[2];
        if ( false !== $pos = strpos($sub_file, '?') )
          $sub_file = substr($sub_file, 0, $pos);

        $title = wptexturize($sub_item[0]);

        if ( ( ('index.php' != $sub_item[2]) && file_exists(WP_PLUGIN_DIR . "/$sub_file") ) || ! empty($menu_hook) ) {
          // If admin.php is the current page or if the parent exists as a file in the plugins or admin dir
          if ( (!$admin_is_parent && file_exists(WP_PLUGIN_DIR . "/$menu_file") && !is_dir(WP_PLUGIN_DIR . "/{$item[2]}")) || file_exists($menu_file) )
            $sub_item_url = add_query_arg( array('page' => $sub_item[2]), $item[2] );
          else
            $sub_item_url = add_query_arg( array('page' => $sub_item[2]), 'admin.php' );
          $sub_item_url = esc_url($sub_item_url);
          echo "<li$class><a href='$sub_item_url'$class$tabindex>$title</a></li>";
        } else {
          echo "<li$class><a href='{$sub_item[2]}'$class$tabindex>$title</a></li>";
        }
      }
      echo "</ul></div>";
    }
    echo "</li>";
  }




  }

  

   /**
   * Adds all the plugin hooks
   *
   *
   * @since 0.5
   */
  function admin_head() {


    $wp_simplify = get_option('wp_simplify');

    if(!is_array($wp_simplify))
      return;


    if(in_array('disable_useless_metaboxes', $wp_simplify)) {

      WP_Simplify::remove_ui_elements('page', array(
        'postcustom',
        'trackbacksdiv',
        'revisionsdiv',
        'slugdiv',
        'authordiv'
        ));
      WP_Simplify::remove_ui_elements('post', array(
        'postcustom',
        'trackbacksdiv',
        'revisionsdiv',
        'slugdiv',
        'authordiv'
        ));

    }


    echo "<style type='text/css'>";

    $home_page_id = get_option('page_on_front');
    if(get_option('show_on_front') == 'page' && !empty($home_page_id))
      echo "#wpbody-content table.page #page-{$home_page_id} { background: #E7E6DB; }";


    if(in_array('disable_change_permalinks_button', $wp_simplify))
      echo "#change_permalinks, #edit-slug-buttons {display:none;}";

    if(in_array('disable_quick_edit_link', $wp_simplify))
      echo ".row-actions .inline {display:none;}";

    if(in_array('disable_wp_logo', $wp_simplify))
      echo "#header-logo {display:none;}";

    echo "</style>";




  }


   /**
   * Saves WP-Simplify settings on General Settings page
   *
   *
   * @since 1.0
   */
   function general_settings_admin() {
   
  
    // Load WP-Simplify settings page script
    wp_enqueue_script('wp-simplify');
    wp_enqueue_script('jquery-ui-tabs');
    wp_enqueue_style('wp-simplify');
      
      
      // Process settings
      if(isset($_REQUEST['wp_simplify_nonce']) && wp_verify_nonce($_REQUEST['wp_simplify_nonce'], "wp_simplify_update")) {      
        update_option('wp_simplify', $_REQUEST['wp_simplify']); 
      }
     

   
   }

   /**
   * Highest level admin-specific functions.
   *
   *
   * @since 1.0
   */
  function admin_init() {

    $wp_simplify = get_option('wp_simplify');

    // Forward non-admins to front-end
    if(is_array($wp_simplify)) {
      if(in_array('disable_backend_access_to_non_admins', $wp_simplify)) {
        if(!current_user_can('level_10') && !current_user_can('access_backend') && !isset($_REQUEST['action'])) {
           header('Location:  ' . get_bloginfo("url"));
          die();
          }
      }
    }
    
    // Register scripts and styles
    wp_register_script('wp-simplify', WP_PLUGIN_URL . '/wp-simplify/js/wp-simplify-admin.js', array('jquery'));
    wp_register_style('wp-simplify', WP_PLUGIN_URL . '/wp-simplify/css/wp-simplify-admin.css');
    
    
    // Add the field with the names and function to use for our new settings, put it in our new section
    add_settings_field('wp_simplify', 'WP-Simplify Settings', array('WP_Simplify', 'settings_page'), 'general');

    // Register our setting so that $_POST handling is done for us and our callback function just has to echo the <input>
    register_setting('general','wp_simplify');

    add_filter('admin_user_info_links', array('WP_Simplify','admin_user_info_links'), 0, 2);

    
    // Enable Post and Page Locking
    if(is_array($wp_simplify) && in_array('allow_post_locking', $wp_simplify))  {
      add_action('post_submitbox_misc_actions',  array('WP_Simplify','show_post_locking_checkbox'));
      add_action('save_post',  array('WP_Simplify','save_post'), 0, 2);
      add_action('delete_post',  array('WP_Simplify','delete_post'));
      add_action('trash_post',  array('WP_Simplify','delete_post'));
      add_filter('post_updated_messages',  array('WP_Simplify','post_updated_messages'));
    }


    // Basecamp Style
    if(is_array($wp_simplify) && in_array('basecamp_style', $wp_simplify))  {
      add_action('wp_admin_css', create_function(' ', " "));
      add_action('in_admin_header', array('WP_Simplify','admin_header'));

      wp_register_style('basecamp', WP_PLUGIN_URL . '/wp-simplify/css/admin-basecamp-style.css', array('colors'));
      wp_enqueue_style('basecamp', WP_PLUGIN_URL . '/wp-simplify/css/admin-basecamp-style.css');
      wp_enqueue_script('basecamp-script', WP_PLUGIN_URL . '/wp-simplify/js/basecamp-script.js', array('jquery'));

    }


  }

  function admin_user_info_links($links, $current_user) {

    $links[5] = str_replace("Howdy, ", "", $links[5]);

    return $links;

  }


   /**
   * Displays checkbox in "Publish" metabox
   *
   * @since 1.0
   */
   function show_post_locking_checkbox() {
    global $post_id; 
    
    $wps_locked_post = get_post_meta($post_id, 'wps_locked_post', true);
   
     ?>
      <div class="misc-pub-section">
        <input type="checkbox" value="true" name="wps_locked_post" value="true" id="wps_locked_post" <?php checked($wps_locked_post, 'true'); ?>/>
        <label for="wps_locked_post"><?php _e('Lock this post and prevent it from being deleted.'); ?></label>
      </div>
    
    <?php
   
   }
   
   /**
   * Displays checkbox in "Publish" metabox
   *
   * @since 1.0
   */
   function save_post($post_ID, $post) {
    

      if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE )
        return $post_id;        

      // Save locked_post status
      update_post_meta($post_ID, 'wps_locked_post', $_REQUEST['wps_locked_post']);   
 
   }
   
      
   /**
   * Displays checkbox in "Publish" metabox
   *
   * @since 1.0
   */
   function delete_post($post_id) {
    
    $wps_locked_post = get_post_meta($post_id, 'wps_locked_post', true);
    
    if($wps_locked_post == 'true') {
    
      wp_redirect(admin_url("post.php?post={$post_id}&action=edit&message=1911"));
      die();
    }      
 
   }
        
   /**
   * Displays checkbox in "Publish" metabox
   *
   * @since 1.0
   */
   function post_updated_messages($messages) {
 
      $messages['post']['1911'] = __('This post is locked so it cannot be deleted or trashed. Unlock first to delete.');
      $messages['page']['1911'] = __('This post is locked so it cannot be deleted or trashed. Unlock first to delete.');
      
      return $messages;
   }
   
   
   
   /**
   * Removes all metaboxes from given page
   *
   * Should be called by function in add_meta_boxes_$post_type
   * Cycles through all metaboxes
   *
   * @since 1.1
   */
   function remove_ui_elements($post_type, $remove_elements) {
    global $wp_meta_boxes, $_wp_post_type_features;


    // Remove Metaboxes
    if(is_array($wp_meta_boxes[$post_type]))
    foreach($wp_meta_boxes[$post_type] as $context_slug => $priority_array) {

      foreach($priority_array as $priority_slug => $meta_box_array) {

        foreach($meta_box_array as $meta_box_slug => $meta_bog_data) {

          if(in_array($meta_box_slug, $remove_elements))
            unset($wp_meta_boxes[$post_type][$context_slug][$priority_slug][$meta_box_slug]);
        }
      }
    }


    if(is_array($_wp_post_type_features[$post_type])) {
      // Remove features
      foreach($_wp_post_type_features[$post_type] as $feature => $enabled) {

        if(in_array($feature, $remove_elements))
          unset($_wp_post_type_features[$post_type][$feature]);

      }
    }
   }




function wp_dashboard_setup() {


  $wp_simplify = get_option('wp_simplify');

  if(!is_array($wp_simplify))
    return;


  if(in_array('disable_dashboard_metaboxes', $wp_simplify)) {
      WP_Simplify::remove_ui_elements('dashboard', array(
      'dashboard_right_now',
      'dashboard_recent_comments',
      'dashboard_incoming_links',
      'dashboard_plugins',
      'dashboard_quick_press',
      'dashboard_recent_drafts',
      'dashboard_primary',
      'dashboard_secondary',
      'dashboard_recent_comments'
      ));


  }




  if(in_array('disable_right_now_widget', $wp_simplify)) {
      WP_Simplify::remove_ui_elements('dashboard', array('dashboard_right_now'));
  }


  if(in_array('disable_comments', $wp_simplify)) {
      WP_Simplify::remove_ui_elements('dashboard', array('dashboard_recent_comments'));

      WP_Simplify::remove_ui_elements('page', array('commentsdiv'));
      WP_Simplify::remove_ui_elements('post', array('commentsdiv'));

  }



  if(in_array('disable_posts', $wp_simplify)) {
      WP_Simplify::remove_ui_elements('dashboard', array('dashboard_quick_press', 'dashboard_recent_drafts'));

  }


}

  function widgets_init() {

  $wp_simplify = get_option('wp_simplify');

  if(!is_array($wp_simplify))
    return;



  if(in_array('disable_comments', $wp_simplify)) {
    unregister_widget('WP_Widget_Recent_Comments');

  }



  if(in_array('disable_posts', $wp_simplify)) {
    unregister_widget('WP_Widget_Archives');
    unregister_widget('WP_Widget_Recent_Posts');
    unregister_widget('WP_Widget_Categories');

  }


  if(in_array('disable_links', $wp_simplify)) {
    unregister_widget('WP_Widget_Links');

  }


 }


 function favorite_actions($actions) {


  $wp_simplify = get_option('wp_simplify');

  if(!is_array($wp_simplify))
    return $actions;



  if(in_array('disable_posts', $wp_simplify)) {
    unset($actions['post-new.php']);
    unset($actions['edit.php?post_status=draft']);

  }

  if(in_array('disable_pages', $wp_simplify)) {
    unset($actions['edit.php?post_type=page']);
    unset($actions['post-new.php?post_type=page']);
  }

  if(in_array('disable_comments', $wp_simplify)) {
    unset($actions['edit-comments.php']);
   }

  if(in_array('disable_media', $wp_simplify)) {
    unset($actions['media-new.php']);
   }


  return $actions;
 }


 function admin_menu() {
  global $menu, $submenu;

  //print_r($menu);

  $wp_simplify = get_option('wp_simplify');

  if(!is_array($wp_simplify))
    return;

  if(in_array('disable_comments', $wp_simplify)) {
    if(function_exists('remove_post_type_support')) {
      remove_post_type_support('post', 'comments');
      remove_post_type_support('page', 'comments');
    }
    unset($menu[25]);

  }

  if(in_array('disable_posts', $wp_simplify))
    unset($menu[5]);


  if(in_array('disable_pages', $wp_simplify))
    unset($menu[20]);


  if(in_array('disable_media', $wp_simplify))
    unset($menu[10]);


  if(in_array('disable_appearance', $wp_simplify))
    unset($menu[60]);

  if(in_array('disable_users', $wp_simplify))
    unset($menu[70]);


  if(in_array('disable_links', $wp_simplify))
    unset($menu[15]);

  if(in_array('rename_posts', $wp_simplify) && $menu[5][0] == 'Posts') {
    $menu[5][0] = 'News';
    $menu[5][3] = 'News';
  }
  if(in_array('rename_cforms', $wp_simplify) && $menu[100][0] == 'cformsII') {
    $menu[100][0] = 'Forms';
    $menu[100][3] = 'Forms';
  }

  if(in_array('rename_shopp', $wp_simplify) && $menu[26][0] == 'Shopp') {
    $menu[26][0] = 'Online Store';
    $menu[26][3] = 'Online Store';
  }


  if(in_array('disable_relocate_admin_menu_links', $wp_simplify)) {
    // Hide plugins from menu
    unset($menu[65]);

    // Hide settings from menu
    unset($menu[80]);

    // Hide tools menu
    unset($menu[75]);
    add_filter('admin_footer_text', array('WP_Simplify','relocated_nav_components'));

  }

  // Save media into temporary variable
  $media_section = $menu[10];

  // Move pages in place of media
  $menu[10] = $menu[20];

  // Put media in place of pages
  $menu[20] = $media_section;


//  print_r($menu);

 }


 function relocated_nav_components() {
  global $submenu;

  $this_menu = $submenu;

  if(is_array($this_menu['plugins.php'] ))  {

    foreach($this_menu['plugins.php'] as $data) {

      if(strpos($data[2], '/') || !strpos($data[2], '.php'))
        $data[2] = 'plugins.php?page=' . $data[2];

      $plugins_menu[] = "<a style='font-style: normal;' href='".admin_url($data[2]) ."'>{$data[0]} </a>";

    }
    echo '<span style="font-style: normal; margin-right: 5px;">Plugins: </span>' . implode(" | " , $plugins_menu) . "<br />";

  }


  if(is_array($this_menu['options-general.php'] ))  {

    foreach($this_menu['options-general.php'] as $data) {

      if(strpos($data[2], '/') || !strpos($data[2], '.php') || !empty($data[3]))
        $data[2] = 'options-general.php?page=' . $data[2];

      $options_menu[] = "<a style='font-style: normal;' href='".admin_url($data[2]) ."'>{$data[0]} </a>";

    }
    echo '<span style="font-style: normal; margin-right: 5px;">Settings: </span>' . implode(" | " , $options_menu) . "<br />";

  }

  if(is_array($this_menu['tools.php'] ))  {

    foreach($this_menu['tools.php'] as $data) {

      if(strpos($data[2], '/') || !strpos($data[2], '.php'))
        $data[2] = 'tools.php?page=' . $data[2];

      $tools_menu[] = "<a style='font-style: normal;' href='".admin_url($data[2]) ."'>{$data[0]} </a>";

    }
    echo '<span style="font-style: normal; margin-right: 5px;">Tools: </span>' . implode(" | " , $tools_menu) . "<br />";

  }



 }


  function settings_page() {
    $checked = "";

    // Mark our checkbox as checked if the setting is already true
    $wp_simplify = get_option('wp_simplify');

    if(!is_array($wp_simplify))
    $wp_simplify = array();


  ?>
  <script type="text/javascript">
    jQuery(document).ready(function() {});
  </script>

  <input type="hidden" name="wp_simplify_nonce" value="<?php echo wp_create_nonce('wp_simplify_update'); ?>" />
  
  <div id="wp_simplify_settings_tabs">
    <ul class="wps_section_tabs">
      <li><a href="#wps_major_compontents"><?php _e('Major Components'); ?></a></li>
      <li><a href="#wps_simplify_ui"><?php _e('Simplify UI'); ?></a></li>
      <li><a href="#wps_miscellaneous"><?php _e('Miscellaneous'); ?></a></li>
      <li><a href="#wps_security"><?php _e('Security'); ?></a></li>
  <?php if(in_array('enabled_advanced_functions', $wp_simplify) ) { ?>
      <li><a href="#wps_advanced_fetures"><?php _e('Advanced Features'); ?></a></li>
  <?php } ?>
    </ul>
  
  
  <div id="wps_major_compontents" class="wp-tab-panel">
    <ul>
      <li><input name='wp_simplify[]' id='disable_posts' type='checkbox' value='disable_posts' class='code'  <?php if(in_array('disable_posts', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_posts"> Disable Posts</label>
      <li><input name='wp_simplify[]' id='disable_pages' type='checkbox' value='disable_pages' class='code'  <?php if(in_array('disable_pages', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_pages"> Disable Pages</label>
      <li><input name='wp_simplify[]' id='disable_links' type='checkbox' value='disable_links' class='code'  <?php if(in_array('disable_links', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_links"> Disable Links</label>
      <li><input name='wp_simplify[]' id='disable_media' type='checkbox' value='disable_media' class='code'  <?php if(in_array('disable_media', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_media"> Disable Media. <span class="description">Images can still be uploaded, this only hides the link from nav menu.</span></label>
      <li><input name='wp_simplify[]' id='disable_comments' type='checkbox' value='disable_comments' class='code' <?php if(in_array('disable_comments', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_comments"> Disable Comments. <span class="description">Doesn't affect the front-end.</span></label>
      <li><input name='wp_simplify[]' id='disable_appearance' type='checkbox' value='disable_appearance' class='code'  <?php if(in_array('disable_appearance', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_appearance"> Disable Appearance</label>
      <li><input name='wp_simplify[]' id='disable_users' type='checkbox' value='disable_users' class='code'  <?php if(in_array('disable_users', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_users"> Disable Users</label>
    </ul>
  </div>


  <div id="wps_simplify_ui" class="wp-tab-panel">
    <ul>
      <li><input name='wp_simplify[]' id='disable_useless_metaboxes' type='checkbox' value='disable_useless_metaboxes' class='code'  <?php if(in_array('disable_useless_metaboxes', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_useless_metaboxes"> Clean up editor screen. <span class="description">disable pingback, author, slug, and page attribute metaboxes.</span></label>
      <li><input name='wp_simplify[]' id='disable_relocate_admin_menu_links' type='checkbox' value='disable_relocate_admin_menu_links' class='code'  <?php if(in_array('disable_relocate_admin_menu_links', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_relocate_admin_menu_links"> Relocate Settings, Tools and Plugins into Footer Text</label>
      <li><input name='wp_simplify[]' id='highlight_homepage' type='checkbox' value='highlight_homepage' class='code'  <?php if(in_array('highlight_homepage', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="highlight_homepage"> If front page is selected to be a static page, highlight it in back-end.</label>
      <li><input name='wp_simplify[]' id='disable_wp_logo' type='checkbox' value='disable_wp_logo' class='code'  <?php if(in_array('disable_wp_logo', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_wp_logo"> Hide the WP logo in the top left corner.</label>
      <li><input name='wp_simplify[]' id='disable_right_now_widget' type='checkbox' value='disable_right_now_widget' class='code'  <?php if(in_array('disable_right_now_widget', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_right_now_widget"> Disable 'Right Now' Dashboard Metabox.  </label>
      <li><input name='wp_simplify[]' id='disable_dashboard_metaboxes' type='checkbox' value='disable_dashboard_metaboxes' class='code'  <?php if(in_array('disable_dashboard_metaboxes', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_dashboard_metaboxes"> Better yet, disable <b>all</b> default dashboard metaboxes.</label>
      <li><input name='wp_simplify[]' id='basecamp_style' type='checkbox' value='basecamp_style' class='code'  <?php if(in_array('basecamp_style', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="basecamp_style"> Change style to look like Basecamp.</label>
    </ul>  
  </div>
  

  <div id="wps_miscellaneous" class="wp-tab-panel">
     <ul>
      <li><input name='wp_simplify[]' id='disable_change_permalinks_button' type='checkbox' value='disable_change_permalinks_button' class='code'  <?php if(in_array('disable_change_permalinks_button', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_change_permalinks_button"> Hide the "Change Permalinks" and "Edit" buttons on post & page edit pages.</label>

      <?php if(function_exists('cforms')): ?>
      <li><input name='wp_simplify[]' id='rename_cforms' type='checkbox' value='rename_cforms' class='code'  <?php if(in_array('rename_cforms', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="rename_cforms"> Rename "cformsII" to "Forms". <span class="description">Phenomenal plugin, not a customer-friendly name.</span></label>
      <?php endif; ?>

      <?php if(class_exists('Shopp')): ?>
      <li><input name='wp_simplify[]' id='rename_shopp' type='checkbox' value='rename_shopp' class='code'  <?php if(in_array('rename_shopp', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="rename_shopp"> Rename "Shopp" to "Online Store".</label>
      <?php endif; ?>
      <li><input name='wp_simplify[]' id='rename_posts' type='checkbox' value='rename_posts' class='code'  <?php if(in_array('rename_posts', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="rename_posts"> Rename "Posts" to "News".</label>

      <li><input name='wp_simplify[]' id='disable_quick_edit_link' type='checkbox' value='disable_quick_edit_link' class='code'  <?php if(in_array('disable_quick_edit_link', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_quick_edit_link"> Hide the "Quick Edit" link on post & page overview pages.</label>
      <li><input name='wp_simplify[]' id='disable_theme_editor' type='checkbox' value='disable_theme_editor' class='code'  <?php if(in_array('disable_theme_editor', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_theme_editor"> Disable theme editing for all users via control panel (prevents potential security risk).</label>
      <li><input name='wp_simplify[]' id='enabled_advanced_functions' type='checkbox' value='enabled_advanced_functions' class='code'  <?php if(in_array('enabled_advanced_functions', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="enabled_advanced_functions"> <?php _e('Enable advanced WP-Simplify functions such as WordPress blanking'); ?><span class="description"> <?php _e('Warning: use advanced features at your own risk.'); ?></span></label>

    </ul>
  </div>

  <div id="wps_security" class="wp-tab-panel">

    <ul>
      <li><input name='wp_simplify[]' id='disable_backend_access_to_non_admins' type='checkbox' value='disable_backend_access_to_non_admins' class='code'  <?php if(in_array('disable_backend_access_to_non_admins', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="disable_backend_access_to_non_admins"> Disable back-end access to non-administrators. <span class="description">If enabled, on attempt to access /wp-admin, non-level 10 administrators will be forwarded to the frontend. This can be overwritten if uses has "access_backend" capability.</span></label>
      <li><input name='wp_simplify[]' id='force_ssl_on_front_end' type='checkbox' value='force_ssl_on_front_end' class='code'  <?php if(in_array('force_ssl_on_front_end', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="force_ssl_on_front_end"> Always use SSL on front-end. <span class="description"></span></label>
      <li><input name='wp_simplify[]' id='allow_post_locking' type='checkbox' value='allow_post_locking' class='code'  <?php if(in_array('allow_post_locking', $wp_simplify)) echo " checked='checked'  "; ?>/><label for="allow_post_locking"> <?php _e('Allow post locking.'); ?><span class="description"><?php _('Willl show checkbox on post and page editing screens which will let you "lock" posts - or prevent them from being deleted.'); ?></span></label>
    </ul>
    
  </div>

  <?php if(in_array('enabled_advanced_functions', $wp_simplify) ) { ?>
  <div id="wps_advanced_fetures" class="wp-tab-panel">
   <span class="wp_simplify_show_advanced" style='cursor: pointer;'><?php _e('Toggle Advanced Functions.'); ?></span>
    <ul class="hidden wp_simplify_advanced_options">
      <li>
        <input type='submit'  value='Blank WordPress' name='blank_wordpress' id='blank_wordpress' />
        <label for="blank_wordpress">
        Warning! Blanking WordPress will remove all posts, pages and post meta.  Do not do this on a live site!
        </label>
      </li>

    </ul>
  </div>
  <?php } /* Advanced Features */  ?>

  </div><?php /* End WP-Simplify Tabs */ ?>



  <?php


 } // settings_page()




 }


 
add_action('after_setup_theme', create_function('', 'new WP_Simplify;'));
